==> ejc-zdsmaterialb-api-3.0.0-20241015.015712-31-sources.jar: com/ejianc/business/zdsmaterial/plan/control/vo/ControlPlanDetailVO.java <==
package com.ejianc.business.zdsmaterial.plan.control.vo;

import java.math.*;
import java.util.ArrayList;
import java.util.List;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资总控计划明细
 * 
 * @author generator
 * 
 */
public class ControlPlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String property; // 属性
    private String propertyValue; // 属性值
    private Long unitId; // 计量单位Id
    private String unitName; // 单位
    private BigDecimal num; // 总控量
    private String memo; // 备注
    private Integer sourceType; // 来源：1-档案，2-新增
    private Integer rowType; // 行类型：1-新增，2-变更
    private String reason; // 超量原因
    private BigDecimal beforeNum; // 变更前总控量
    private BigDecimal afterNum; // 变更后总控量
    private BigDecimal purchaseNum; // 累计采购量
    private Long parentMaterialTypeId; // 二级分类主键
    private Integer hasNewPropertyVal; // 是否新增属性值：0-否，1-是
    private String productCode; // 产品代码
    private String materialTypeCode; // 物资分类编码
    private Long brandId; //品牌主键
    private String brandName; // 品牌名称
    private String errorMsg; // 错误信息
    private String description; // 描述
    private Integer matchState; // 匹配结果：1-完全匹配，2-历史匹配，3-模糊匹配
    private String parentMaterialTypeCode; // 二级分类编码
    private String parentMaterialTypeName; // 二级分类名称
    private String detailIndex; // 序号


    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public String getParentMaterialTypeCode() {
        return parentMaterialTypeCode;
    }

    public void setParentMaterialTypeCode(String parentMaterialTypeCode) {
        this.parentMaterialTypeCode = parentMaterialTypeCode;
    }

    public String getParentMaterialTypeName() {
        return parentMaterialTypeName;
    }

    public void setParentMaterialTypeName(String parentMaterialTypeName) {
        this.parentMaterialTypeName = parentMaterialTypeName;
    }
    private List<ControlPlanDetailVO> matchList = new ArrayList<>(); // 匹配结果


    public List<ControlPlanDetailVO> getMatchList() {
        return matchList;
    }

    public void setMatchList(List<ControlPlanDetailVO> matchList) {
        this.matchList = matchList;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getMatchState() {
        return matchState;
    }

    public void setMatchState(Integer matchState) {
        this.matchState = matchState;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    @ReferSerialTransfer(referCode="ref-zdsBrand")
    public Long getBrandId() {
        return brandId;
    }

    @ReferDeserialTransfer
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public BigDecimal getBeforeNum() {
        return beforeNum;
    }

    public void setBeforeNum(BigDecimal beforeNum) {
        this.beforeNum = beforeNum;
    }

    public BigDecimal getAfterNum() {
        return afterNum;
    }

    public void setAfterNum(BigDecimal afterNum) {
        this.afterNum = afterNum;
    }

    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }

    public Long getParentMaterialTypeId() {
        return parentMaterialTypeId;
    }

    public void setParentMaterialTypeId(Long parentMaterialTypeId) {
        this.parentMaterialTypeId = parentMaterialTypeId;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }
    
}

==> ejc-zdsmaterialb-api-3.0.0-20251111.015046-80-sources.jar: com/ejianc/business/zdsmaterial/plan/control/vo/ControlPlanDetailVO.java <==
package com.ejianc.business.zdsmaterial.plan.control.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 物资总控计划明细
 * 
 * @author generator
 * 
 */
public class ControlPlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String property; // 属性
    private String propertyValue; // 属性值
    private Long unitId; // 计量单位Id
    private String unitName; // 单位
    private BigDecimal num; // 总控量
    private String memo; // 备注
    private Integer sourceType; // 来源：1-档案，2-新增
    private Integer rowType; // 行类型：1-新增，2-变更
    private String reason; // 超量原因
    private BigDecimal beforeNum; // 变更前总控量
    private BigDecimal afterNum; // 变更后总控量
    private BigDecimal purchaseNum; // 累计采购量
    private Long parentMaterialTypeId; // 二级分类主键
    private Integer hasNewPropertyVal; // 是否新增属性值：0-否，1-是
    private String productCode; // 产品代码
    private String materialTypeCode; // 物资分类编码
    private Long brandId; //品牌主键
    private String brandName; // 品牌名称
    private String errorMsg; // 错误信息
    private String description; // 描述
    private Integer matchState; // 匹配结果：1-完全匹配，2-历史匹配，3-模糊匹配
    private String parentMaterialTypeCode; // 二级分类编码
    private String parentMaterialTypeName; // 二级分类名称
    private String detailIndex; // 序号

    private String identificationId; // 物料识别唯一标识
    private String originalInMaterialName; //初始导入物料名称
    private String originalInMaterialSpec; //初始导入物料规格型号
    private String originalInMaterialUnitName; //初始导入物料单位

    /**
     * 切包改造====
     */
    private Long materialPackId; // 切包情况-材料包id，二级物料类别
    private String materialPackCode; // 切包情况-材料包编码
    private String materialPackName; // 切包情况-材料包名称
    private String itemCode; // 清单编码
    private String itemName; // 清单名称
    private String budgetType; // 1:切包请单内2：切包清单外
    private Long budgetDetailId; // 清单子表ID
    /**
     * 切包改造end=====
     */

    public Long getMaterialPackId() {
        return materialPackId;
    }

    public void setMaterialPackId(Long materialPackId) {
        this.materialPackId = materialPackId;
    }

    public String getMaterialPackCode() {
        return materialPackCode;
    }

    public void setMaterialPackCode(String materialPackCode) {
        this.materialPackCode = materialPackCode;
    }

    public String getMaterialPackName() {
        return materialPackName;
    }

    public void setMaterialPackName(String materialPackName) {
        this.materialPackName = materialPackName;
    }

    public String getItemCode() {
        return itemCode;
    }

    public void setItemCode(String itemCode) {
        this.itemCode = itemCode;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getBudgetType() {
        return budgetType;
    }

    public void setBudgetType(String budgetType) {
        this.budgetType = budgetType;
    }

    public Long getBudgetDetailId() {
        return budgetDetailId;
    }

    public void setBudgetDetailId(Long budgetDetailId) {
        this.budgetDetailId = budgetDetailId;
    }

    public String getIdentificationId() {
        return identificationId;
    }

    public void setIdentificationId(String identificationId) {
        this.identificationId = identificationId;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public String getParentMaterialTypeCode() {
        return parentMaterialTypeCode;
    }

    public void setParentMaterialTypeCode(String parentMaterialTypeCode) {
        this.parentMaterialTypeCode = parentMaterialTypeCode;
    }

    public String getParentMaterialTypeName() {
        return parentMaterialTypeName;
    }

    public void setParentMaterialTypeName(String parentMaterialTypeName) {
        this.parentMaterialTypeName = parentMaterialTypeName;
    }
    private List<ControlPlanDetailVO> matchList = new ArrayList<>(); // 匹配结果


    public List<ControlPlanDetailVO> getMatchList() {
        return matchList;
    }

    public void setMatchList(List<ControlPlanDetailVO> matchList) {
        this.matchList = matchList;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getMatchState() {
        return matchState;
    }

    public void setMatchState(Integer matchState) {
        this.matchState = matchState;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    @ReferSerialTransfer(referCode="ref-zdsBrand")
    public Long getBrandId() {
        return brandId;
    }

    @ReferDeserialTransfer
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public BigDecimal getBeforeNum() {
        return beforeNum;
    }

    public void setBeforeNum(BigDecimal beforeNum) {
        this.beforeNum = beforeNum;
    }

    public BigDecimal getAfterNum() {
        return afterNum;
    }

    public void setAfterNum(BigDecimal afterNum) {
        this.afterNum = afterNum;
    }

    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }

    public Long getParentMaterialTypeId() {
        return parentMaterialTypeId;
    }

    public void setParentMaterialTypeId(Long parentMaterialTypeId) {
        this.parentMaterialTypeId = parentMaterialTypeId;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getOriginalInMaterialName() {
        return originalInMaterialName;
    }

    public void setOriginalInMaterialName(String originalInMaterialName) {
        this.originalInMaterialName = originalInMaterialName;
    }

    public String getOriginalInMaterialSpec() {
        return originalInMaterialSpec;
    }

    public void setOriginalInMaterialSpec(String originalInMaterialSpec) {
        this.originalInMaterialSpec = originalInMaterialSpec;
    }

    public String getOriginalInMaterialUnitName() {
        return originalInMaterialUnitName;
    }

    public void setOriginalInMaterialUnitName(String originalInMaterialUnitName) {
        this.originalInMaterialUnitName = originalInMaterialUnitName;
    }
}
